import time
import board
import usb_hid
import adafruit_vl53l0x
from adafruit_hid.keyboard import Keyboard
from adafruit_hid.keycode import Keycode

# Use the built-in STEMMA QT port on the QT Py RP2040
i2c = board.STEMMA_I2C()

# Initialize ToF sensor
tof = adafruit_vl53l0x.VL53L0X(i2c)
tof.measurement_timing_budget = 50000  # 50ms per reading (balanced)

# Initialize HID keyboard
keyboard = Keyboard(usb_hid.devices)

# Distance thresholds (in millimeters)
TRIGGER_DISTANCE_MM = 280
RESET_DISTANCE_MM = 310

# Simple moving average filter
buffer_size = 3
distance_buffer = []
for _ in range(buffer_size):
    try:
        distance_buffer.append(tof.range)
    except:
        distance_buffer.append(500)  # Safe default
    time.sleep(0.01)

armed = True
debug_counter = 0

while True:
    try:
        # Get new reading
        raw_distance = tof.range

        # Update buffer (remove oldest, add newest)
        distance_buffer.pop(0)
        distance_buffer.append(raw_distance)

        # Calculate average
        avg_distance = sum(distance_buffer) / len(distance_buffer)

        # Debug output (only print every 10 cycles to reduce serial clutter)
        debug_counter += 1
        if debug_counter >= 10:
            print("Raw:", raw_distance, "Avg:", avg_distance, "Armed:", armed)
            debug_counter = 0

        # Check thresholds using average distance
        if armed and avg_distance < TRIGGER_DISTANCE_MM:
            print("TRIGGER - Distance:", avg_distance, "mm")
            keyboard.press(Keycode.TAB)
            time.sleep(0.01)  # Small delay to ensure press registers
            keyboard.release(Keycode.TAB)
            print(">>> TAB key pressed!")
            armed = False

        elif not armed and avg_distance > RESET_DISTANCE_MM:
            armed = True
            print("Re-armed")

    except Exception as e:
        print("Error:", e)

    time.sleep(0.03)  # Small delay between readings